@@ -6,11 +6,13 @@ use File::Spec::Functions qw( catdir updir );
 use FindBin               qw( $Bin );
 use lib               catdir( $Bin, updir, 'lib' ), catdir( $Bin, 'lib' );
 
-use Test::More;
-use Test::Requires { version => 0.88 };
 use Module::Build;
 use Sys::Hostname;
 
+sub plan (;@) {
+   $_[ 0 ] eq 'skip_all' and print '1..0 # SKIP '.$_[ 1 ]."\n" and exit 0;
+}
+
 my ($builder, $host, $notes, $perl_ver);
 
 BEGIN {
@@ -19,14 +21,18 @@ BEGIN {
    $notes    = $builder ? $builder->notes : {};
    $perl_ver = $notes->{min_perl_version} || 5.008;
 
+   eval { require Test::Requires }; $@ and plan skip_all => 'No Test::Requires';
+
+   $Bin =~ m{ : .+ : }mx and plan skip_all => 'Two colons in $Bin path';
+
    if ($notes->{testing}) {
-      $Bin =~ m{ : .+ : }mx    and plan skip_all => 'Two colons in $Bin path';
       $host eq 'vm-debian-001' and plan skip_all =>
          'Broken smoker 04fd9956-2ca5-11e5-8be5-d039436f2841';
    }
 }
 
 use Test::Requires "${perl_ver}";
+use Test::Requires { version => 0.88 };
 
 sub import {
    strict->import;
